@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -77,11 +77,11 @@ public class ValidatorAction implements Serializable {
 
     /**
      * <p>
-     * The method signature of the validation method. This should be a comma delimited list of the full class names of each parameter in the correct order that
+     * The method signature of the validation method. This should be a comma-delimited list of the full class names of each parameter in the correct order that
      * the method takes.
      * </p>
      * <p>
-     * Note: <code>java.lang.Object</code> is reserved for the JavaBean that is being validated. The <code>ValidatorAction</code> and <code>Field</code> that
+     * Note: {@code java.lang.Object} is reserved for the JavaBean that is being validated. The {@code ValidatorAction} and {@code Field} that
      * are associated with a field's validation will automatically be populated if they are specified in the method signature.
      * </p>
      */
@@ -93,8 +93,8 @@ public class ValidatorAction implements Serializable {
     private Class<?>[] parameterClasses;
 
     /**
-     * The other <code>ValidatorAction</code>s that this one depends on. If any errors occur in an action that this one depends on, this action will not be
-     * processsed.
+     * The other {@code ValidatorAction}s that this one depends on. If any errors occur in an action that this one depends on, this action will not be
+     * processed.
      */
     private String depends;
 
@@ -114,7 +114,7 @@ public class ValidatorAction implements Serializable {
     private String jsFunction;
 
     /**
-     * An optional field to containing a JavaScript representation of the Java method assocated with this action.
+     * An optional field to containing a JavaScript representation of the Java method associated with this action.
      */
     private String javascript;
 
@@ -124,7 +124,7 @@ public class ValidatorAction implements Serializable {
     private Object instance;
 
     /**
-     * An internal List representation of the other <code>ValidatorAction</code>s this one depends on (if any). This List gets updated whenever setDepends()
+     * An internal List representation of the other {@code ValidatorAction}s this one depends on (if any). This List gets updated whenever setDepends()
      * gets called. This is synchronized so a call to setDepends() (which clears the List) won't interfere with a call to isDependency().
      */
     private final List<String> dependencyList = Collections.synchronizedList(new ArrayList<>());
@@ -134,6 +134,13 @@ public class ValidatorAction implements Serializable {
      */
     private final List<String> methodParameterList = new ArrayList<>();
 
+    /**
+     * Constructs a new instance.
+     */
+    public ValidatorAction() {
+        // empty
+    }
+
     /**
      * Dynamically runs the validation method for this validator and returns true if the data is valid.
      *
@@ -151,19 +158,19 @@ public class ValidatorAction implements Serializable {
         params.put(Validator.VALIDATOR_ACTION_PARAM, this);
 
         try {
-            if (this.validationMethod == null) {
+            if (validationMethod == null) {
                 synchronized (this) {
-                    final ClassLoader loader = this.getClassLoader(params);
-                    this.loadValidationClass(loader);
-                    this.loadParameterClasses(loader);
-                    this.loadValidationMethod();
+                    final ClassLoader loader = getClassLoader(params);
+                    loadValidationClass(loader);
+                    loadParameterClasses(loader);
+                    loadValidationMethod();
                 }
             }
 
-            final Object[] paramValues = this.getParameterValues(params);
+            final Object[] paramValues = getParameterValues(params);
 
             if (field.isIndexed()) {
-                this.handleIndexedField(field, pos, paramValues);
+                handleIndexedField(field, pos, paramValues);
             }
 
             Object result = null;
@@ -183,9 +190,9 @@ public class ValidatorAction implements Serializable {
                 }
             }
 
-            final boolean valid = this.isValid(result);
+            final boolean valid = isValid(result);
             if (!valid || valid && !onlyReturnErrors(params)) {
-                results.add(field, this.name, valid, result);
+                results.add(field, name, valid, result);
             }
 
             if (!valid) {
@@ -201,7 +208,7 @@ public class ValidatorAction implements Serializable {
 
             getLog().error("Unhandled exception thrown during validation: " + e.getMessage(), e);
 
-            results.add(field, this.name, false);
+            results.add(field, name, false);
             return false;
         }
 
@@ -212,9 +219,9 @@ public class ValidatorAction implements Serializable {
      * @return A file name suitable for passing to a {@link ClassLoader#getResourceAsStream(String)} method.
      */
     private String formatJavaScriptFileName() {
-        String fname = this.jsFunction.substring(1);
+        String fname = jsFunction.substring(1);
 
-        if (!this.jsFunction.startsWith("/")) {
+        if (!jsFunction.startsWith("/")) {
             fname = jsFunction.replace('.', '/') + ".js";
         }
 
@@ -252,12 +259,12 @@ public class ValidatorAction implements Serializable {
     }
 
     /**
-     * Returns the dependent validator names as an unmodifiable <code>List</code>.
+     * Returns the dependent validator names as an unmodifiable {@code List}.
      *
-     * @return List of the validator action's depedents.
+     * @return List of the validator action's dependents.
      */
     public List<String> getDependencyList() {
-        return Collections.unmodifiableList(this.dependencyList);
+        return Collections.unmodifiableList(dependencyList);
     }
 
     /**
@@ -266,7 +273,7 @@ public class ValidatorAction implements Serializable {
      * @return The validator action's dependencies.
      */
     public String getDepends() {
-        return this.depends;
+        return depends;
     }
 
     /**
@@ -346,10 +353,10 @@ public class ValidatorAction implements Serializable {
      */
     private Object[] getParameterValues(final Map<String, ? super Object> params) {
 
-        final Object[] paramValue = new Object[this.methodParameterList.size()];
+        final Object[] paramValue = new Object[methodParameterList.size()];
 
-        for (int i = 0; i < this.methodParameterList.size(); i++) {
-            final String paramClassName = this.methodParameterList.get(i);
+        for (int i = 0; i < methodParameterList.size(); i++) {
+            final String paramClassName = methodParameterList.get(i);
             paramValue[i] = params.get(paramClassName);
         }
 
@@ -357,23 +364,23 @@ public class ValidatorAction implements Serializable {
     }
 
     /**
-     * Return an instance of the validation class or null if the validation method is static so does not require an instance to be executed.
+     * Gets an instance of the validation class or null if the validation method is static so does not require an instance to be executed.
      */
     private Object getValidationClassInstance() throws ValidatorException {
-        if (Modifier.isStatic(this.validationMethod.getModifiers())) {
-            this.instance = null;
+        if (Modifier.isStatic(validationMethod.getModifiers())) {
+            instance = null;
 
-        } else if (this.instance == null) {
+        } else if (instance == null) {
             try {
-                this.instance = this.validationClass.getConstructor().newInstance();
-            } catch (ReflectiveOperationException e) {
-                final String msg1 = "Couldn't create instance of " + this.className + ".  " + e.getMessage();
+                instance = validationClass.getConstructor().newInstance();
+            } catch (final ReflectiveOperationException e) {
+                final String msg1 = "Couldn't create instance of " + className + ".  " + e.getMessage();
 
                 throw new ValidatorException(msg1);
             }
         }
 
-        return this.instance;
+        return instance;
     }
 
     private Validator getValidator(final Map<String, Object> params) {
@@ -389,8 +396,8 @@ public class ValidatorAction implements Serializable {
      */
     private void handleIndexedField(final Field field, final int pos, final Object[] paramValues) throws ValidatorException {
 
-        final int beanIndex = this.methodParameterList.indexOf(Validator.BEAN_PARAM);
-        final int fieldIndex = this.methodParameterList.indexOf(Validator.FIELD_PARAM);
+        final int beanIndex = methodParameterList.indexOf(Validator.BEAN_PARAM);
+        final int fieldIndex = methodParameterList.indexOf(Validator.FIELD_PARAM);
 
         final Object[] indexedList = field.getIndexedProperty(paramValues[beanIndex]);
 
@@ -409,7 +416,7 @@ public class ValidatorAction implements Serializable {
      * Initialize based on set.
      */
     protected void init() {
-        this.loadJavascriptFunction();
+        loadJavascriptFunction();
     }
 
     /**
@@ -419,11 +426,11 @@ public class ValidatorAction implements Serializable {
      * @return Whether the named validator is a dependant.
      */
     public boolean isDependency(final String validatorName) {
-        return this.dependencyList.contains(validatorName);
+        return dependencyList.contains(validatorName);
     }
 
     /**
-     * If the result object is a <code>Boolean</code>, it will return its value. If not it will return {@code false} if the object is <code>null</code> and
+     * If the result object is a {@code Boolean}, it will return its value. If not it will return {@code false} if the object is {@code null} and
      * {@code true} if it isn't.
      */
     private boolean isValid(final Object result) {
@@ -438,19 +445,19 @@ public class ValidatorAction implements Serializable {
      * @return true if the JavaScript for this action has already been loaded.
      */
     private boolean javaScriptAlreadyLoaded() {
-        return this.javascript != null;
+        return javascript != null;
     }
 
     /**
-     * Load the JavaScript function specified by the given path. For this implementation, the <code>jsFunction</code> property should contain a fully qualified
+     * Load the JavaScript function specified by the given path. For this implementation, the {@code jsFunction} property should contain a fully qualified
      * package and script name, separated by periods, to be loaded from the class loader that created this instance.
      *
-     * TODO if the path begins with a '/' the path will be intepreted as absolute, and remain unchanged. If this fails then it will attempt to treat the path as
+     * TODO if the path begins with a '/' the path will be interpreted as absolute, and remain unchanged. If this fails then it will attempt to treat the path as
      * a file path. It is assumed the script ends with a '.js'.
      */
     protected synchronized void loadJavascriptFunction() {
 
-        if (this.javaScriptAlreadyLoaded()) {
+        if (javaScriptAlreadyLoaded()) {
             return;
         }
 
@@ -458,17 +465,17 @@ public class ValidatorAction implements Serializable {
             getLog().trace("  Loading function begun");
         }
 
-        if (this.jsFunction == null) {
-            this.jsFunction = this.generateJsFunction();
+        if (jsFunction == null) {
+            jsFunction = generateJsFunction();
         }
 
-        final String javaScriptFileName = this.formatJavaScriptFileName();
+        final String javaScriptFileName = formatJavaScriptFileName();
 
         if (getLog().isTraceEnabled()) {
             getLog().trace("  Loading js function '" + javaScriptFileName + "'");
         }
 
-        this.javascript = this.readJavaScriptFile(javaScriptFileName);
+        javascript = readJavaScriptFile(javaScriptFileName);
 
         if (getLog().isTraceEnabled()) {
             getLog().trace("  Loading JavaScript function completed");
@@ -484,14 +491,14 @@ public class ValidatorAction implements Serializable {
      */
     private void loadParameterClasses(final ClassLoader loader) throws ValidatorException {
 
-        if (this.parameterClasses != null) {
+        if (parameterClasses != null) {
             return;
         }
 
-        final Class<?>[] parameterClasses = new Class[this.methodParameterList.size()];
+        final Class<?>[] parameterClasses = new Class[methodParameterList.size()];
 
-        for (int i = 0; i < this.methodParameterList.size(); i++) {
-            final String paramClassName = this.methodParameterList.get(i);
+        for (int i = 0; i < methodParameterList.size(); i++) {
+            final String paramClassName = methodParameterList.get(i);
 
             try {
                 parameterClasses[i] = loader.loadClass(paramClassName);
@@ -512,12 +519,12 @@ public class ValidatorAction implements Serializable {
      */
     private void loadValidationClass(final ClassLoader loader) throws ValidatorException {
 
-        if (this.validationClass != null) {
+        if (validationClass != null) {
             return;
         }
 
         try {
-            this.validationClass = loader.loadClass(this.className);
+            validationClass = loader.loadClass(className);
         } catch (final ClassNotFoundException e) {
             throw new ValidatorException(e.toString());
         }
@@ -529,12 +536,12 @@ public class ValidatorAction implements Serializable {
      * @throws ValidatorException
      */
     private void loadValidationMethod() throws ValidatorException {
-        if (this.validationMethod != null) {
+        if (validationMethod != null) {
             return;
         }
 
         try {
-            this.validationMethod = this.validationClass.getMethod(this.method, this.parameterClasses);
+            validationMethod = validationClass.getMethod(method, parameterClasses);
 
         } catch (final NoSuchMethodException e) {
             throw new ValidatorException("No such validation method: " + e.getMessage());
@@ -555,10 +562,10 @@ public class ValidatorAction implements Serializable {
      * The search order is described in the documentation for {@link ClassLoader#getResource(String)}.
      * </p>
      *
-     * @param name The resource name
+     * @param javaScriptFileName The resource name
      * @return An input stream for reading the resource, or {@code null} if the resource could not be found
      */
-    private InputStream openInputStream(final String javaScriptFileName, ClassLoader classLoader) {
+    private InputStream openInputStream(final String javaScriptFileName, final ClassLoader classLoader) {
         InputStream is = null;
         if (classLoader != null) {
             is = classLoader.getResourceAsStream(javaScriptFileName);
@@ -629,14 +636,14 @@ public class ValidatorAction implements Serializable {
     public void setDepends(final String depends) {
         this.depends = depends;
 
-        this.dependencyList.clear();
+        dependencyList.clear();
 
         final StringTokenizer st = new StringTokenizer(depends, ",");
         while (st.hasMoreTokens()) {
             final String depend = st.nextToken().trim();
 
             if (depend != null && !depend.isEmpty()) {
-                this.dependencyList.add(depend);
+                dependencyList.add(depend);
             }
         }
     }
@@ -657,15 +664,15 @@ public class ValidatorAction implements Serializable {
     /**
      * Sets the fully qualified class path of the JavaScript function.
      * <p>
-     * This is optional and can be used <strong>instead</strong> of the setJavascript(). Attempting to call both <code>setJsFunction</code> and
-     * <code>setJavascript</code> will result in an <code>IllegalStateException</code> being thrown.
+     * This is optional and can be used <strong>instead</strong> of the setJavascript(). Attempting to call both {@code setJsFunction} and
+     * {@code setJavascript} will result in an {@code IllegalStateException} being thrown.
      * </p>
      * <p>
-     * If <strong>neither</strong> setJsFunction or setJavascript is set then validator will attempt to load the default JavaScript definition.
+     * If <strong>neither</strong> setJsFunction nor setJavascript is set then validator will attempt to load the default JavaScript definition.
      * </p>
      *
      * <pre>
-     * <b>Examples</b>
+     * <strong>Examples</strong>
      *   If in the validator.xml :
      * #1:
      *      &lt;validator name="tire"
@@ -715,14 +722,14 @@ public class ValidatorAction implements Serializable {
     public void setMethodParams(final String methodParams) {
         this.methodParams = methodParams;
 
-        this.methodParameterList.clear();
+        methodParameterList.clear();
 
         final StringTokenizer st = new StringTokenizer(methodParams, ",");
         while (st.hasMoreTokens()) {
             final String value = st.nextToken().trim();
 
             if (value != null && !value.isEmpty()) {
-                this.methodParameterList.add(value);
+                methodParameterList.add(value);
             }
         }
     }
