@@ -6,7 +6,7 @@
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
  *
- *      http://www.apache.org/licenses/LICENSE-2.0
+ *      https://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -21,6 +21,7 @@ import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
 
+import org.apache.commons.validator.GenericValidator;
 import org.apache.commons.validator.routines.checkdigit.CheckDigit;
 import org.apache.commons.validator.routines.checkdigit.LuhnCheckDigit;
 
@@ -34,7 +35,7 @@ import org.apache.commons.validator.routines.checkdigit.LuhnCheckDigit;
  * </p>
  *
  * <pre>
- * <code>CreditCardValidator ccv = new CreditCardValidator(CreditCardValidator.AMEX + CreditCardValidator.VISA);</code>
+ * {@code CreditCardValidator ccv = new CreditCardValidator(CreditCardValidator.AMEX + CreditCardValidator.VISA);}
  * </pre>
  *
  * <p>
@@ -87,11 +88,11 @@ public class CreditCardValidator implements Serializable {
      * @since 1.6
      */
     public static class CreditCardRange {
-        final String low; // e.g. 34 or 644
-        final String high; // e.g. 34 or 65
-        final int minLen; // e.g. 16 or -1
-        final int maxLen; // e.g. 19 or -1
-        final int lengths[]; // e.g. 16,18,19
+        final String low; // for example, 34 or 644
+        final String high; // for example, 34 or 65
+        final int minLen; // for example, 16 or -1
+        final int maxLen; // for example, 19 or -1
+        final int[] lengths; // for example, 16,18,19
 
         /**
          * Create a credit card range specifier for use in validation
@@ -103,7 +104,7 @@ public class CreditCardValidator implements Serializable {
          * </p>
          * <p>
          * The low and high parameters may be different lengths.
-         * e.g. Discover "644" and "65".
+         * for example, Discover "644" and "65".
          * </p>
          * @param low the low digits of the IIN range
          * @param high the high digits of the IIN range
@@ -128,7 +129,7 @@ public class CreditCardValidator implements Serializable {
          * </p>
          * <p>
          * The low and high parameters may be different lengths.
-         * e.g. Discover "644" and "65".
+         * for example, Discover "644" and "65".
          * </p>
          * @param low the low digits of the IIN range
          * @param high the high digits of the IIN range
@@ -155,11 +156,11 @@ public class CreditCardValidator implements Serializable {
      * default cards with this option.
      *
      * <pre>
-     * <code>
+     * {@code
      * CreditCardValidator v = new CreditCardValidator(CreditCardValidator.NONE);
      * v.addAllowedCardType(customType);
      * v.isValid(aCardNumber);
-     * </code>
+     * }
      * </pre>
      */
     public static final long NONE = 0;
@@ -248,14 +249,14 @@ public class CreditCardValidator implements Serializable {
      * </ul>
      */
     private static final RegexValidator MASTERCARD_REGEX = new RegexValidator(
-            "^(5[1-5]\\d{14})$",  // 51 - 55 (pre Oct 2016)
+            "^(5[1-5]\\d{14})$",   // 51 - 55 (pre Oct 2016)
             // valid from October 2016
-            "^(2221\\d{12})$",    // 222100 - 222199
-            "^(222[2-9]\\d{12})$",// 222200 - 222999
-            "^(22[3-9]\\d{13})$", // 223000 - 229999
-            "^(2[3-6]\\d{14})$",  // 230000 - 269999
-            "^(27[01]\\d{13})$",  // 270000 - 271999
-            "^(2720\\d{12})$"     // 272000 - 272099
+            "^(2221\\d{12})$",     // 222100 - 222199
+            "^(222[2-9]\\d{12})$", // 222200 - 222999
+            "^(22[3-9]\\d{13})$",  // 223000 - 229999
+            "^(2[3-6]\\d{14})$",   // 230000 - 269999
+            "^(27[01]\\d{13})$",   // 270000 - 271999
+            "^(2720\\d{12})$"      // 272000 - 272099
         );
 
     /** Mastercard Card Validator */
@@ -443,41 +444,40 @@ public class CreditCardValidator implements Serializable {
      */
     public CreditCardValidator(final long options) {
         if (isOn(options, VISA)) {
-            this.cardTypes.add(VISA_VALIDATOR);
+            cardTypes.add(VISA_VALIDATOR);
         }
 
         if (isOn(options, VPAY)) {
-            this.cardTypes.add(VPAY_VALIDATOR);
+            cardTypes.add(VPAY_VALIDATOR);
         }
 
         if (isOn(options, AMEX)) {
-            this.cardTypes.add(AMEX_VALIDATOR);
+            cardTypes.add(AMEX_VALIDATOR);
         }
 
         if (isOn(options, MASTERCARD)) {
-            this.cardTypes.add(MASTERCARD_VALIDATOR);
+            cardTypes.add(MASTERCARD_VALIDATOR);
         }
 
         if (isOn(options, MASTERCARD_PRE_OCT2016)) {
-            this.cardTypes.add(MASTERCARD_VALIDATOR_PRE_OCT2016);
+            cardTypes.add(MASTERCARD_VALIDATOR_PRE_OCT2016);
         }
 
         if (isOn(options, DISCOVER)) {
-            this.cardTypes.add(DISCOVER_VALIDATOR);
+            cardTypes.add(DISCOVER_VALIDATOR);
         }
 
         if (isOn(options, DINERS)) {
-            this.cardTypes.add(DINERS_VALIDATOR);
+            cardTypes.add(DINERS_VALIDATOR);
         }
     }
 
     /**
-     * Tests whether the given flag is on.  If the flag is not a power of 2
-     * (ie. 3) this tests whether the combination of flags is on.
+     * Tests whether the given flag is on. If the flag is not a power of 2
+     * (for example, 3) this tests whether the combination of flags is on.
      *
      * @param options The options specified.
      * @param flag Flag value to check.
-     *
      * @return whether the specified flag value is on.
      */
     private boolean isOn(final long options, final long flag) {
@@ -490,7 +490,7 @@ public class CreditCardValidator implements Serializable {
      * @return Whether the card number is valid.
      */
     public boolean isValid(final String card) {
-        if (card == null || card.isEmpty()) {
+        if (GenericValidator.isBlankOrNull(card)) {
             return false;
         }
         for (final CodeValidator cardType : cardTypes) {
@@ -504,11 +504,11 @@ public class CreditCardValidator implements Serializable {
     /**
      * Checks if the field is a valid credit card number.
      * @param card The card number to validate.
-     * @return The card number if valid or <code>null</code>
+     * @return The card number if valid or {@code null}
      * if invalid.
      */
     public Object validate(final String card) {
-        if (card == null || card.isEmpty()) {
+        if (GenericValidator.isBlankOrNull(card)) {
             return null;
         }
         Object result = null;
